@@ -5,9 +5,13 @@ use crate::prelude::LifecycleState;
 use std::sync::mpsc::TryRecvError;
 
 /// Runs a gtk main loop while listening to the given store.
-pub fn run<F, A, S>(store: crate::store::Store<A, S>, window: F)
+/// # Arguments
+/// - store: The store is used to send a startup action.
+/// - startup: A callback that is triggered when the application is started.
+///
+pub fn run<F, A, S>(store: crate::store::Store<A, S>, startup: F)
 where
-    F: Fn(crate::store::Store<A, S>) -> gtk::ApplicationWindow + 'static,
+    F: Fn(crate::store::Store<A, S>, &gtk::Application) -> gtk::ApplicationWindow + 'static,
     A: Send + Clone + Eq + 'static,
     S: LifecycleState + Clone + Eq + Default + 'static,
 {
@@ -44,8 +48,8 @@ where
 
     let gtk_app = gtk::ApplicationBuilder::new().build();
 
-    gtk_app.connect_startup(move |_| {
-        window(store.clone());
+    gtk_app.connect_startup(move |app| {
+        startup(store.clone(), app);
     });
 
     gtk_app.connect_activate(move |_| {
